==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/parsing.api/src/org/netbeans/modules/parsing/spi/EmbeddingProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
     * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.parsing.spi;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.List;
import org.netbeans.modules.parsing.api.Embedding;
import org.netbeans.modules.parsing.api.Snapshot;
import org.netbeans.modules.parsing.spi.indexing.support.QuerySupport;


/**
 * EmbeddingProvider returns sources for embedded languages ({@link Embedding}s)
 * based on lexical analyse of current snapshot. Embedded
 * source can consist from one or more blocks of original source and it can contain
 * some generated parts that has no mirror in the original text. See 
 * {@link Snapshot} class for more information how to create embedded source.
 *
 * @author Jan Jancura
 */
public abstract class EmbeddingProvider extends SchedulerTask {
    
    
    /**
     * Returns {@link Scheduler} class for this SchedulerTask. See
     * {@link Scheduler} documentation for a list of default schedulers,
     * or your your own implementation.
     * 
     * @return              {@link Scheduler} for this SchedulerTask.
     */
    public final Class<? extends Scheduler> getSchedulerClass () {
        return null;
    }

    /**
     * Returns list of {@link Embedding}s based on lexical analyse.
     * 
     * @param snapshot      A snapshot that should be scanned for embeddings.
     * @return              List of {@link Embedding}s.
     */
    public abstract List<Embedding> getEmbeddings (Snapshot snapshot);
    
    /**
     * Returns priority of this source provider.
     * @return              priority of this source provider
     */
    public abstract int getPriority ();

    /**
     * Registration of the {@link EmbeddingProvider}.
     * Creates a mime lookup registration of the {@link TaskFactory} for
     * annotated {@link EmbeddingProvider}. It also provides the target
     * mime type of the created embedding which allows the {@link QuerySupport}
     * to correctly mark dirty embedded indexers.
     *
     * @since 1.57
     */
    @Retention(RetentionPolicy.SOURCE)
    @Target(ElementType.TYPE)
    public @interface Registration {

        /**
         * Mime type to which should be the given {@link EmbeddingProvider} registered.
         */
         public String mimeType();

        /**
         * Mime type of the embedding created by the registered {@link EmbeddingProvider}
         */
        String targetMimeType();
    }
}

==> netbeans_8.1+dfsg3.orig.tar.xz: netbeans-8.1/parsing.api/src/org/netbeans/modules/parsing/spi/EmbeddingProvider.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
     * 
 * Contributor(s):
 * 
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.modules.parsing.spi;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import java.util.List;
import org.netbeans.modules.parsing.api.Embedding;
import org.netbeans.modules.parsing.api.Snapshot;


/**
 * EmbeddingProvider returns sources for embedded languages ({@link Embedding}s)
 * based on lexical analyse of current snapshot. Embedded
 * source can consist from one or more blocks of original source and it can contain
 * some generated parts that has no mirror in the original text. See 
 * {@link Snapshot} class for more information how to create embedded source.
 *
 * @author Jan Jancura
 */
public abstract class EmbeddingProvider extends SchedulerTask {
    
    
    /**
     * Returns {@link Scheduler} class for this SchedulerTask. See
     * {@link Scheduler} documentation for a list of default schedulers,
     * or your your own implementation.
     * 
     * @return              {@link Scheduler} for this SchedulerTask.
     */
    public final Class<? extends Scheduler> getSchedulerClass () {
        return null;
    }

    /**
     * Returns list of {@link Embedding}s based on lexical analyse.
     * 
     * @param snapshot      A snapshot that should be scanned for embeddings.
     * @return              List of {@link Embedding}s.
     */
    public abstract List<Embedding> getEmbeddings (Snapshot snapshot);
    
    /**
     * Returns priority of this source provider.
     * @return              priority of this source provider
     */
    public abstract int getPriority ();

    /**
     * Registration of the {@link EmbeddingProvider}.
     * Creates a mime lookup registration of the {@link TaskFactory} for
     * annotated {@link EmbeddingProvider}. It also provides the target
     * mime type of the created embedding which allows the indexing QuerySupport
     * to correctly mark dirty embedded indexers.
     *
     * @since 1.57
     */
    @Retention(RetentionPolicy.SOURCE)
    @Target(ElementType.TYPE)
    public @interface Registration {

        /**
         * Mime type to which should be the given {@link EmbeddingProvider} registered.
         */
         public String mimeType();

        /**
         * Mime type of the embedding created by the registered {@link EmbeddingProvider}
         */
        String targetMimeType();
    }
}
